==> xfe_2.0.1.orig.tar.xz: xfe-2.0.1/src/icons.h <==
#ifndef ICONS_H
#define ICONS_H


// Prototypes
FXbool loadAppIcons(FXApp*, FXbool*);


// Icons (global variables)
extern FXIcon* bigattribicon;
extern FXIcon* bigblockdevicon;
extern FXIcon* bigbrokenlinkicon;
extern FXIcon* bigcdromicon;
extern FXIcon* bigchardevicon;
extern FXIcon* bigcompareicon;
extern FXIcon* bigdocicon;
extern FXIcon* bigexecicon;
extern FXIcon* bigfileopenicon;
extern FXIcon* bigfiltericon;
extern FXIcon* bigfloppyicon;
extern FXIcon* bigfoldericon;
extern FXIcon* bigfolderopenicon;
extern FXIcon* bigfolderlockedicon;
extern FXIcon* bigfolderupicon;
extern FXIcon* bigfolderlinkicon;
extern FXIcon* bigfoldernewicon;
extern FXIcon* bigfolderremoteicon;
extern FXIcon* bigharddriveicon;
extern FXIcon* bignewfileicon;
extern FXIcon* bignewlinkicon;
extern FXIcon* bignetdriveicon;
extern FXIcon* bignetdriveumticon;
extern FXIcon* bigpipeicon;
extern FXIcon* bigsocketicon;
extern FXIcon* bigzipdiskicon;
extern FXIcon* bigrenameicon;
extern FXIcon* bigbookmarkicon;
extern FXIcon* bigaddbookicon;
extern FXIcon* bigeditbookicon;
extern FXIcon* bigremovebookicon;
extern FXIcon* bigcopyicon;
extern FXIcon* bigdeletepermicon;
extern FXIcon* bigdeleteicon;
extern FXIcon* bigerroricon;
extern FXIcon* biggotoicon;
extern FXIcon* biglinktoicon;
extern FXIcon* biglinkicon;
extern FXIcon* biginfoicon;
extern FXIcon* bigmoveicon;
extern FXIcon* bigprinticon;
extern FXIcon* bigquestionicon;
extern FXIcon* bigtrashfullicon;
extern FXIcon* bigwarningicon;
extern FXIcon* bigrestoreicon;
extern FXIcon* bigarchaddicon;
extern FXIcon* bigarchexticon;
extern FXIcon* bigkeybindingsicon;
extern FXIcon* bigsearchicon;
extern FXIcon* bigreplaceicon;
extern FXIcon* bigrunicon;
extern FXIcon* biglinkbadgeicon;

extern FXIcon* miniarchaddicon;
extern FXIcon* miniarchexticon;
extern FXIcon* miniattribicon;
extern FXIcon* minibigiconsicon;
extern FXIcon* minicdromicon;
extern FXIcon* minicharticon;
extern FXIcon* miniclosefileicon;
extern FXIcon* minibookmarkicon;
extern FXIcon* miniaddbookicon;
extern FXIcon* minieditbookicon;
extern FXIcon* miniremovebookicon;
extern FXIcon* minicolltreeicon;
extern FXIcon* minicopyicon;
extern FXIcon* minicuticon;
extern FXIcon* miniunselicon;
extern FXIcon* minidetailsicon;
extern FXIcon* minidirupicon;
extern FXIcon* miniediticon;
extern FXIcon* miniexptreeicon;
extern FXIcon* minideletepermicon;
extern FXIcon* minideleteicon;
extern FXIcon* minifileopenicon;
extern FXIcon* miniviewicon;
extern FXIcon* minifiltericon;
extern FXIcon* minicompareicon;
extern FXIcon* minifindagainicon;
extern FXIcon* minifliplricon;
extern FXIcon* miniflipudicon;
extern FXIcon* minifloppyicon;
extern FXIcon* minifontsicon;
extern FXIcon* minigotodiricon;
extern FXIcon* minigotoicon;
extern FXIcon* miniharddriveicon;
extern FXIcon* minihelpicon;
extern FXIcon* minihidehiddenicon;
extern FXIcon* minihidenumbersicon;
extern FXIcon* minihidethumbicon;
extern FXIcon* minihomeicon;
extern FXIcon* minidesktopicon;
extern FXIcon* miniinvselicon;
extern FXIcon* minilowercaseicon;
extern FXIcon* minimounticon;
extern FXIcon* miniappicon;
extern FXIcon* miniblockdevicon;
extern FXIcon* minibrokenlinkicon;
extern FXIcon* minichardevicon;
extern FXIcon* minidocicon;
extern FXIcon* miniexecicon;
extern FXIcon* minifolderlockedicon;
extern FXIcon* minifolderopenicon;
extern FXIcon* minifoldericon;
extern FXIcon* minifolderlinkicon;
extern FXIcon* minifolderupicon;
extern FXIcon* minifolderremoteicon;
extern FXIcon* minifoldernewicon;
extern FXIcon* minifolderhomeicon;
extern FXIcon* minifolderdownloadicon;
extern FXIcon* minifolderdocumentsicon;
extern FXIcon* minifolderimagesicon;
extern FXIcon* minifoldermusicicon;
extern FXIcon* minifoldervideosicon;
extern FXIcon* minilinktoicon;
extern FXIcon* minilinkicon;
extern FXIcon* minipipeicon;
extern FXIcon* minishellicon;
extern FXIcon* minisocketicon;
extern FXIcon* minimoveicon;
extern FXIcon* mininewfileicon;
extern FXIcon* mininetdriveicon;
extern FXIcon* mininetdriveumticon;
extern FXIcon* minionepanelicon;
extern FXIcon* minipackageicon;
extern FXIcon* minipasteicon;
extern FXIcon* miniprefsicon;
extern FXIcon* miniprinticon;
extern FXIcon* miniquiticon;
extern FXIcon* miniredoicon;
extern FXIcon* minireloadicon;
extern FXIcon* minirenameicon;
extern FXIcon* minireplaceicon;
extern FXIcon* minireverticon;
extern FXIcon* minirotatelefticon;
extern FXIcon* minirotaterighticon;
extern FXIcon* minirunicon;
extern FXIcon* minisaveasicon;
extern FXIcon* minisavefileicon;
extern FXIcon* minisearchnexticon;
extern FXIcon* minisearchicon;
extern FXIcon* minisearchprevicon;
extern FXIcon* miniselallicon;
extern FXIcon* minishowhiddenicon;
extern FXIcon* minishownumbersicon;
extern FXIcon* minishowthumbicon;
extern FXIcon* minismalliconsicon;
extern FXIcon* minitrashfullicon;
extern FXIcon* minitreeonepanelicon;
extern FXIcon* minitreetwopanelsicon;
extern FXIcon* minitwopanelsicon;
extern FXIcon* miniundoicon;
extern FXIcon* miniunmounticon;
extern FXIcon* miniuppercaseicon;
extern FXIcon* miniworkicon;
extern FXIcon* miniwrapofficon;
extern FXIcon* miniwraponicon;
extern FXIcon* minizipdiskicon;
extern FXIcon* minizoom100icon;
extern FXIcon* minizoominicon;
extern FXIcon* minizoomouticon;
extern FXIcon* minizoomwinicon;
extern FXIcon* minitotrashicon;
extern FXIcon* minidirbackicon;
extern FXIcon* minidirforwardicon;
extern FXIcon* minixferooticon;
extern FXIcon* minixfeicon;
extern FXIcon* minifiledialogicon;
extern FXIcon* miniswitchpanelsicon;
extern FXIcon* minisyncpanelsicon;
extern FXIcon* mininewlinkicon;
extern FXIcon* minigreenbuttonicon;
extern FXIcon* minigraybuttonicon;
extern FXIcon* minikeybindingsicon;
extern FXIcon* minirestoreicon;
extern FXIcon* minihorzpanelsicon;
extern FXIcon* minivertpanelsicon;
extern FXIcon* minitreeicon;
extern FXIcon* miniplacesicon;
extern FXIcon* miniupicon;
extern FXIcon* minidownicon;
extern FXIcon* miniremovabledeviceicon;
extern FXIcon* miniclosefiltericon;
extern FXIcon* minilinkbadgeicon;

extern FXIcon* xfeicon;
extern FXIcon* xfaicon;
extern FXIcon* xfiicon;
extern FXIcon* xfpicon;
extern FXIcon* xfwicon;

extern FXIcon* cmymodeicon;
extern FXIcon* dialmodeicon;
extern FXIcon* eyedropicon;
extern FXIcon* hsvmodeicon;
extern FXIcon* listmodeicon;
extern FXIcon* rgbmodeicon;

#endif

==> xfe_2.1.1.orig.tar.xz: xfe-2.1.1/src/icons.h <==
#ifndef ICONS_H
#define ICONS_H


// Icon path found status
enum
{
    ICONPATH_FOUND,
    ICONPATH_NOT_FOUND,
    ICONPATH_MISSING_ICONS,
    DEFAULTICONPATH_NOT_FOUND,
};


// Prototypes
FXbool loadAppIcons(FXApp*, FXuint*);


// Icons (global variables)
extern FXIcon* bigattribicon;
extern FXIcon* bigblockdevicon;
extern FXIcon* bigbrokenlinkicon;
extern FXIcon* bigcdromicon;
extern FXIcon* bigchardevicon;
extern FXIcon* bigcompareicon;
extern FXIcon* bigdocicon;
extern FXIcon* bigexecicon;
extern FXIcon* bigfileopenicon;
extern FXIcon* bigfiltericon;
extern FXIcon* bigfloppyicon;
extern FXIcon* bigfoldericon;
extern FXIcon* bigfolderopenicon;
extern FXIcon* bigfolderlockedicon;
extern FXIcon* bigfolderupicon;
extern FXIcon* bigfolderlinkicon;
extern FXIcon* bigfoldernewicon;
extern FXIcon* bigfolderremoteicon;
extern FXIcon* bigharddriveicon;
extern FXIcon* bignewfileicon;
extern FXIcon* bignewlinkicon;
extern FXIcon* bignetdriveicon;
extern FXIcon* bignetdriveumticon;
extern FXIcon* bigpipeicon;
extern FXIcon* bigsocketicon;
extern FXIcon* bigzipdiskicon;
extern FXIcon* bigrenameicon;
extern FXIcon* bigbookmarkicon;
extern FXIcon* bigaddbookicon;
extern FXIcon* bigeditbookicon;
extern FXIcon* bigremovebookicon;
extern FXIcon* bigcopyicon;
extern FXIcon* bigdeletepermicon;
extern FXIcon* bigdeleteicon;
extern FXIcon* bigerroricon;
extern FXIcon* biggotoicon;
extern FXIcon* biglinktoicon;
extern FXIcon* biglinkicon;
extern FXIcon* biginfoicon;
extern FXIcon* bigmoveicon;
extern FXIcon* bigprinticon;
extern FXIcon* bigquestionicon;
extern FXIcon* bigtrashfullicon;
extern FXIcon* bigwarningicon;
extern FXIcon* bigrestoreicon;
extern FXIcon* bigarchaddicon;
extern FXIcon* bigarchexticon;
extern FXIcon* bigkeybindingsicon;
extern FXIcon* bigsearchicon;
extern FXIcon* bigreplaceicon;
extern FXIcon* bigrunicon;
extern FXIcon* biglinkbadgeicon;
extern FXIcon* bigsavefileicon;
extern FXIcon* bigsaveasicon;
extern FXIcon* bigservericon;

extern FXIcon* miniarchaddicon;
extern FXIcon* miniarchexticon;
extern FXIcon* miniattribicon;
extern FXIcon* minibigiconsicon;
extern FXIcon* minicdromicon;
extern FXIcon* minicharticon;
extern FXIcon* miniclosefileicon;
extern FXIcon* minibookmarkicon;
extern FXIcon* miniaddbookicon;
extern FXIcon* minieditbookicon;
extern FXIcon* miniremovebookicon;
extern FXIcon* minicolltreeicon;
extern FXIcon* minicopyicon;
extern FXIcon* minicuticon;
extern FXIcon* miniunselicon;
extern FXIcon* minidetailsicon;
extern FXIcon* minidirupicon;
extern FXIcon* miniediticon;
extern FXIcon* miniexptreeicon;
extern FXIcon* minideletepermicon;
extern FXIcon* minideleteicon;
extern FXIcon* minifileopenicon;
extern FXIcon* miniviewicon;
extern FXIcon* minifiltericon;
extern FXIcon* minicompareicon;
extern FXIcon* minifindagainicon;
extern FXIcon* minifliplricon;
extern FXIcon* miniflipudicon;
extern FXIcon* minifloppyicon;
extern FXIcon* minifontsicon;
extern FXIcon* minigotodiricon;
extern FXIcon* minigotoicon;
extern FXIcon* miniharddriveicon;
extern FXIcon* minihelpicon;
extern FXIcon* minihidehiddenicon;
extern FXIcon* minihidenumbersicon;
extern FXIcon* minihidethumbicon;
extern FXIcon* minihomeicon;
extern FXIcon* minidesktopicon;
extern FXIcon* miniinvselicon;
extern FXIcon* minilowercaseicon;
extern FXIcon* minimounticon;
extern FXIcon* miniappicon;
extern FXIcon* miniblockdevicon;
extern FXIcon* minibrokenlinkicon;
extern FXIcon* minichardevicon;
extern FXIcon* minidocicon;
extern FXIcon* miniexecicon;
extern FXIcon* minifolderlockedicon;
extern FXIcon* minifolderopenicon;
extern FXIcon* minifoldericon;
extern FXIcon* minifolderlinkicon;
extern FXIcon* minifolderupicon;
extern FXIcon* minifolderremoteicon;
extern FXIcon* minifoldernewicon;
extern FXIcon* minifolderhomeicon;
extern FXIcon* minifolderdownloadicon;
extern FXIcon* minifolderdocumentsicon;
extern FXIcon* minifolderimagesicon;
extern FXIcon* minifoldermusicicon;
extern FXIcon* minifoldervideosicon;
extern FXIcon* minilinktoicon;
extern FXIcon* minilinkicon;
extern FXIcon* minipipeicon;
extern FXIcon* minishellicon;
extern FXIcon* minisocketicon;
extern FXIcon* minimoveicon;
extern FXIcon* mininewfileicon;
extern FXIcon* mininetdriveicon;
extern FXIcon* mininetdriveumticon;
extern FXIcon* minionepanelicon;
extern FXIcon* minipackageicon;
extern FXIcon* minipasteicon;
extern FXIcon* miniprefsicon;
extern FXIcon* miniprinticon;
extern FXIcon* miniquiticon;
extern FXIcon* miniredoicon;
extern FXIcon* minireloadicon;
extern FXIcon* minirenameicon;
extern FXIcon* minireplaceicon;
extern FXIcon* minireverticon;
extern FXIcon* minirotatelefticon;
extern FXIcon* minirotaterighticon;
extern FXIcon* minirunicon;
extern FXIcon* minisaveasicon;
extern FXIcon* minisavefileicon;
extern FXIcon* minisearchnexticon;
extern FXIcon* minisearchicon;
extern FXIcon* minisearchprevicon;
extern FXIcon* miniselallicon;
extern FXIcon* minishowhiddenicon;
extern FXIcon* minishownumbersicon;
extern FXIcon* minishowthumbicon;
extern FXIcon* minismalliconsicon;
extern FXIcon* minitrashfullicon;
extern FXIcon* minitreeonepanelicon;
extern FXIcon* minitreetwopanelsicon;
extern FXIcon* minitwopanelsicon;
extern FXIcon* miniundoicon;
extern FXIcon* miniunmounticon;
extern FXIcon* miniuppercaseicon;
extern FXIcon* miniworkicon;
extern FXIcon* miniwrapofficon;
extern FXIcon* miniwraponicon;
extern FXIcon* minizipdiskicon;
extern FXIcon* minizoom100icon;
extern FXIcon* minizoominicon;
extern FXIcon* minizoomouticon;
extern FXIcon* minizoomwinicon;
extern FXIcon* minitotrashicon;
extern FXIcon* minidirbackicon;
extern FXIcon* minidirforwardicon;
extern FXIcon* minixferooticon;
extern FXIcon* minixfeicon;
extern FXIcon* minifiledialogicon;
extern FXIcon* miniswitchpanelsicon;
extern FXIcon* minisyncpanelsicon;
extern FXIcon* mininewlinkicon;
extern FXIcon* minigreenbuttonicon;
extern FXIcon* minigraybuttonicon;
extern FXIcon* minikeybindingsicon;
extern FXIcon* minirestoreicon;
extern FXIcon* minihorzpanelsicon;
extern FXIcon* minivertpanelsicon;
extern FXIcon* minitreeicon;
extern FXIcon* miniplacesicon;
extern FXIcon* miniupicon;
extern FXIcon* minidownicon;
extern FXIcon* miniremovabledeviceicon;
extern FXIcon* miniclosefiltericon;
extern FXIcon* minilinkbadgeicon;
extern FXIcon* minicloseicon;
extern FXIcon* miniaddicon;
extern FXIcon* mininewtabicon;
extern FXIcon* miniremovetabicon;
extern FXIcon* miniservericon;

extern FXIcon* xfeicon;
extern FXIcon* xfaicon;
extern FXIcon* xfiicon;
extern FXIcon* xfpicon;
extern FXIcon* xfwicon;

extern FXIcon* cmymodeicon;
extern FXIcon* dialmodeicon;
extern FXIcon* eyedropicon;
extern FXIcon* hsvmodeicon;
extern FXIcon* listmodeicon;
extern FXIcon* rgbmodeicon;

extern FXIcon* docktopicon;
extern FXIcon* dockbottomicon;
extern FXIcon* docklefticon;
extern FXIcon* dockrighticon;
extern FXIcon* dockflipicon;
extern FXIcon* dockfreeicon;

#endif
